jagon

package
v0.0.0-...-7fe9b57 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2018 License: MIT Imports: 2 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Apostles

func Apostles(c *gin.Context)

Apostles gives some information about the current apostotles.

func Confess

func Confess(c *gin.Context)

Confess alows you to confess to the almighty Jagon !

func DoSacrifice

func DoSacrifice(c *gin.Context)

DoSacrifice allows you to sacrifice something in the name of Jagon

func Praise

func Praise(c *gin.Context)

Praise allows you to praise the almighty Jagon.

func Pray

func Pray(c *gin.Context)

Pray allows you to pray the almighty Jagon.

func Prophet

func Prophet(c *gin.Context)

Prophet gives some information about the current prophet.

Types

type Confession

type Confession struct {
	Confession string `json:"confession,omitempty"`
}

Confession is a simple confession.

type Sacrifice

type Sacrifice struct {
	What string `json:"what,omitempty"`
}

Sacrifice represents a single sacrifice

Jump to