package
Version:
v0.0.0-...-7fe9b57
Opens a new window with list of versions in this module.
Published: Mar 2, 2018
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
Apostles gives some information about the current apostotles.
Confess alows you to confess to the almighty Jagon !
DoSacrifice allows you to sacrifice something in the name of Jagon
Praise allows you to praise the almighty Jagon.
Pray allows you to pray the almighty Jagon.
Prophet gives some information about the current prophet.
type Confession struct {
Confession string `json:"confession,omitempty"`
}
Confession is a simple confession.
type Sacrifice struct {
What string `json:"what,omitempty"`
}
Sacrifice represents a single sacrifice
Source Files
¶
Click to show internal directories.
Click to hide internal directories.